#
# spec file for package docker-compose
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define mod_name compose

Name:           docker-compose
Version:        1.6.2
Release:        8.1
Summary:        Define and run complex applications using Docker
License:        Apache-2.0
Group:          System/Management
Url:            https://pypi.python.org/pypi/fig
Source0:        %{mod_name}-%{version}.tar.xz
Source1:        README.SUSE
Patch0:         fix-requirements.patch
Requires:       docker
Requires:       python-PyYAML           >= 3.11
Conflicts:      python-PyYAML           >= 4
Requires:       python-docker-py        >= 1.7.0
Conflicts:      python-docker-py        >= 2
Requires:       python-dockerpty        >= 0.4.1
Conflicts:      python-dockerpty        >= 0.5
Requires:       python-docopt           >= 0.6.1
Conflicts:      python-docopt           >= 0.7
Requires:       python-enum34           >= 1.0
Conflicts:      python-enum34           >= 2
Requires:       python-jsonschema       >= 2.5.1
Conflicts:      python-jsonschema       >= 3
Requires:       python-requests         >= 2.7.0
Conflicts:      python-requests         >= 2.10
Requires:       python-setuptools
Requires:       python-six              >= 1.7.3
Conflicts:      python-six              >= 2
Requires:       python-texttable        >= 0.8.2
Conflicts:      python-texttable        >= 0.9
Requires:       python-websocket-client >= 0.32.0
Conflicts:      python-websocket-client >= 1.0
Requires:       python-cached-property  >= 1.2.0
Conflicts:      python-cached-property  >= 2
BuildRequires:  python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Compose is a tool for defining and running complex applications with Docker.
With Compose, you define a multi-container application in a single file, then
spin your application up in a single command which does everything that needs
to be done to get it running.

Compose is great for development environments, staging servers, and CI. We
don't recommend that you use it in production yet.

Previously known as Fig.

%prep
%setup -q -n %{mod_name}-%{version}
%patch0 -p1
cp %{SOURCE1} .

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE README.md CHANGES.md SWARM.md README.SUSE
%{_bindir}/docker-compose
%dir %{python_sitelib}/*
%{python_sitelib}/compose/*
%{python_sitelib}/*egg-info/*

%changelog
* Thu Mar 17 2016 opensuse-packaging@opensuse.org
- Update to version 1.6.2:
  + Add failing test for --abort-on-container-exit
  + Stop other containers if the flag is set.
  + Revert "Change special case from '_', None to ()"
  + Make environment variables without a value the same as docker-cli.
  + Updating Dockerfile
  + Bump 1.6.1
  + Update docker-py version in requirements to 1.7.2
  + Bump 1.6.2
- add cached-property requirement
- review version requirements so we don't have surprises if python
  packages are updated
- fix fix-requirements.patch based on versions in Factory
  This fixes bsc#954145, docker-compose provided by tumbleweed does not run
* Mon Dec 21 2015 fcastelli@suse.com
- Update to version 1.5.2:
  * Fixed a bug which broke the use of environment and env_file with extends,
    and caused environment keys without values to have a None value, instead of
    a value from the host environment.
  * Fixed a regression in 1.5.1 that caused a warning about volumes to be
    raised incorrectly when containers were recreated.
  * Fixed a bug which prevented building a Dockerfile that used ADD <url>
  * Fixed a bug with docker-compose restart which prevented it from starting
    stopped containers.
  * Fixed handling of SIGTERM and SIGINT to properly stop containers
  * Add support for using a url as the value of build
  * Improved the validation of the expose option
* Thu Nov 19 2015 fcastelli@suse.com
- Add fix-requirements.patch: require the version of python-enum34
  shipped with SLE and openSUSE. The original version is not really
  needed.
- Downgraded python-enum34 requirement to suit what is already shipped
  with SLE/openSUSE
* Sun Nov 15 2015 jmassaguerpla@suse.com
- Update to docker-compose 1.5.1
  Remove fix_requires.patch because latest version requires different
  versions of the previous packages
  Changelog: https://github.com/docker/compose/blob/1.5.1/CHANGELOG.md
* Tue Jul 28 2015 fcastelli@suse.com
- Fix python-request requirement
  Updated fix_requires.patch: required to fix docker-compose on Factory
* Mon Jul 27 2015 hvogel@suse.com
- Update to version 1.3.2
* Tue Jul 21 2015 fcastelli@suse.com
- Updated fix_requires.patch: required to fix docker-compose on Factory
* Fri Jul 10 2015 fcastelli@suse.com
- Added fix_requires.patch: required to have docker-compose running
* Fri May 29 2015 fcastelli@suse.com
- Add README.SUSE
* Fri Apr 17 2015 fcastelli@suse.com
- Update to version 1.2.0
* Fri Apr 10 2015 fcastelli@suse.com
- Removed python-backports.ssl_match_hostname from the runtime deps,
  this belongs to python-requests
* Thu Apr  9 2015 fcastelli@suse.com
- Added missing runtime dependency python-backports.ssl_match_hostname
* Thu Apr  9 2015 fcastelli@suse.com
- Added missing runtime requirement python-setuptools
* Thu Apr  9 2015 fcastelli@suse.com
- Created initial package targeting v1.2.0rc3
